@@ -1,9 +1,9 @@
 
 #' default registries
 #'
-#' A helper function to conviently load the default registries
+#' A helper function to conveniently load the default registries
 #' @details This function is primarily useful to restrict the
-#' scope of [query_sources] or [register] to, e.g. either just the
+#' scope of [sources] or [register] to, e.g. either just the
 #' remote registry or just the local registry.  Note that a user
 #' can alter the registry on the fly by passing local paths and/or the
 #' URL (`https://hash-archive.org`) directly.
@@ -13,17 +13,15 @@
 #' default_registries()
 #'
 #' ## Only the fist one (local registry)
-#' default_registry()[1]
+#' default_registries()[1]
 #' \donttest{
 #' ## Alter the defaults with env var.
-#' ## here we set two local registries as the defaults
-#' Sys.setenv(CONTENTID_REGISTRIES = "store/, store2/")
+#' Sys.setenv(CONTENTID_REGISTRIES = tempfile())
 #' default_registries()
 #'
-#' Sys.unsetenv(CONTENTID_REGISTRIES)
+#' Sys.unsetenv("CONTENTID_REGISTRIES")
 #' }
-#' @noRd
-# @export
+#' @export
 default_registries <- function() {
   registries <- strsplit(
     Sys.getenv(
@@ -31,6 +29,7 @@ default_registries <- function() {
       paste(
         default_tsv(),                           ## local registry
         "https://hash-archive.org",              ## Hash Archives
+        "https://hash-archive.carlboettiger.info",
         "https://archive.softwareheritage.org",  
         "https://cn.dataone.org",
         "https://zenodo.org",
